==> estateplat-common-1.2.3-20180129.063043-22-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfZlhtFwgk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 租赁合同房屋概况
 */
@Table(name = "ls_fcjy_clf_zlht_fwgk")
public class LsFcjyClfZlhtFwgk implements InsertVo {
    @Id
    private String id;//主键
    private String zlhtid;//租赁合同id
    private String hbh;//户编号
    private String fwzl;//房屋坐落
    private String cqzh;//产权证号
    private String szc;//所在层
    private String fwjg;//房屋结构
    private String fwyt;//房屋用途
    private Double jzmj;//建筑面积
    private Double ftmj;//分摊面积
    private String tdsyqlx;//土地使用权类型
    private String fzss;//附着设施
    private String wxyhxs;//维修养护形式
    private String wxfycd;//维修费用承担
    private String ygfysm;//有关费用说明
    private String qtsm;//其他说明

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getZlhtid() {
        return zlhtid;
    }

    public void setZlhtid(String zlhtid) {
        this.zlhtid = zlhtid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getFwyt() {
        return fwyt;
    }

    public void setFwyt(String fwyt) {
        this.fwyt = fwyt;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public String getFzss() {
        return fzss;
    }

    public void setFzss(String fzss) {
        this.fzss = fzss;
    }

    public String getWxyhxs() {
        return wxyhxs;
    }

    public void setWxyhxs(String wxyhxs) {
        this.wxyhxs = wxyhxs;
    }

    public String getWxfycd() {
        return wxfycd;
    }

    public void setWxfycd(String wxfycd) {
        this.wxfycd = wxfycd;
    }

    public String getYgfysm() {
        return ygfysm;
    }

    public void setYgfysm(String ygfysm) {
        this.ygfysm = ygfysm;
    }

    public String getQtsm() {
        return qtsm;
    }

    public void setQtsm(String qtsm) {
        this.qtsm = qtsm;
    }
}

==> estateplat-common-1.2.3-20180223.044413-30-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfZlhtFwgk.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 租赁合同房屋概况
 */
@Table(name = "ls_fcjy_clf_zlht_fwgk")
public class LsFcjyClfZlhtFwgk implements InsertVo {
    @Id
    private String id;//主键
    private String zlhtid;//租赁合同id
    private String hbh;//户编号
    private String fwzl;//房屋坐落
    private String cqzh;//产权证号
    private String szc;//所在层
    private String fwjg;//房屋结构
    private String ghyt;//房屋用途
    private Double jzmj;//建筑面积
    private Double ftmj;//分摊面积
    private String tdsyqlx;//土地使用权类型
    private String fzss;//附着设施
    private String wxyhxs;//维修养护形式
    private String wxfycd;//维修费用承担
    private String ygfysm;//有关费用说明
    private String qtsm;//其他说明
    private String fwlx;//房屋类型
    private String fwxz;//房屋性质
    private String yfwlx;//原房屋类型
    private String yfwxz;//原房屋性质
    private String yfwjg;//原房屋结构
    private String yghyt;//原房屋用途

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getZlhtid() {
        return zlhtid;
    }

    public void setZlhtid(String zlhtid) {
        this.zlhtid = zlhtid;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwzl() {
        return fwzl;
    }

    public void setFwzl(String fwzl) {
        this.fwzl = fwzl;
    }

    public String getCqzh() {
        return cqzh;
    }

    public void setCqzh(String cqzh) {
        this.cqzh = cqzh;
    }

    public String getSzc() {
        return szc;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getFwjg() {
        return fwjg;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public Double getJzmj() {
        return jzmj;
    }

    public void setJzmj(Double jzmj) {
        this.jzmj = jzmj;
    }

    public Double getFtmj() {
        return ftmj;
    }

    public void setFtmj(Double ftmj) {
        this.ftmj = ftmj;
    }

    public String getTdsyqlx() {
        return tdsyqlx;
    }

    public void setTdsyqlx(String tdsyqlx) {
        this.tdsyqlx = tdsyqlx;
    }

    public String getFzss() {
        return fzss;
    }

    public void setFzss(String fzss) {
        this.fzss = fzss;
    }

    public String getWxyhxs() {
        return wxyhxs;
    }

    public void setWxyhxs(String wxyhxs) {
        this.wxyhxs = wxyhxs;
    }

    public String getWxfycd() {
        return wxfycd;
    }

    public void setWxfycd(String wxfycd) {
        this.wxfycd = wxfycd;
    }

    public String getYgfysm() {
        return ygfysm;
    }

    public void setYgfysm(String ygfysm) {
        this.ygfysm = ygfysm;
    }

    public String getQtsm() {
        return qtsm;
    }

    public void setQtsm(String qtsm) {
        this.qtsm = qtsm;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getYfwlx() {
        return yfwlx;
    }

    public void setYfwlx(String yfwlx) {
        this.yfwlx = yfwlx;
    }

    public String getYfwxz() {
        return yfwxz;
    }

    public void setYfwxz(String yfwxz) {
        this.yfwxz = yfwxz;
    }

    public String getYfwjg() {
        return yfwjg;
    }

    public void setYfwjg(String yfwjg) {
        this.yfwjg = yfwjg;
    }

    public String getYghyt() {
        return yghyt;
    }

    public void setYghyt(String yghyt) {
        this.yghyt = yghyt;
    }
}
